@@ -65,11 +65,10 @@ r_to_py.factor <- function(x, convert = FALSE) {
 
 #' @export
 r_to_py.POSIXt <- function(x, convert = FALSE) {
-
   tz <- attr(x, "tzone", TRUE)
 
   ## POSIXlt tzone is a length-3 vec, where "" means local/missing tzone
-  if(length(tz))
+  if (length(tz))
     tz <- tz[[1L]] %""% NULL
 
   # we prefer numpy datetime64 for efficiency
@@ -80,14 +79,22 @@ r_to_py.POSIXt <- function(x, convert = FALSE) {
     return(np_array$astype(dtype = "datetime64[ns]"))
   }
 
-  if(!is.null(tz)) {
-    if(py_version() >= "3.9")
+  if (!is.null(tz)) {
+    if (py_version() >= "3.9")
       tz <- import("zoneinfo", convert = FALSE)$ZoneInfo(tz)
     else
       tz <- import("pytz")$timezone(tz)
   }
   datetime <- import("datetime", convert = FALSE)
-  datetime$datetime$fromtimestamp(as.double(x), tz = tz)
+  x <- as.double(x)
+  if (length(x) == 1L) {
+    datetime$datetime$fromtimestamp(x, tz = tz)
+  } else {
+    r_to_py_impl(
+      lapply(x, datetime$datetime$fromtimestamp, tz = tz),
+      convert = FALSE
+    )
+  }
 }
 
 
@@ -267,7 +274,7 @@ py_to_r.datatable.Frame <- function(x) {
 
 #' @export
 py_to_r.pandas.core.frame.DataFrame <- function(x) {
-  local_conversion_scope(x, TRUE)
+  local_conversion_scope(x, FALSE)
 
   np <- import("numpy", convert = TRUE)
   pandas <- import("pandas", convert = TRUE)
@@ -282,12 +289,12 @@ py_to_r.pandas.core.frame.DataFrame <- function(x) {
   })
 
   # assign colnamnes
-  columns <- py_set_convert(x$columns, FALSE)$values
+  columns <- x$columns$values
   columns <- as.character(bt$list(x$columns$map(bt$str)))
   names(converted) <- columns
 
   df <- converted
-  attr(df, "row.names") <- c(NA_integer_, -x$shape[[1L]])
+  attr(df, "row.names") <- c(NA_integer_, py_to_r(-x$shape[[0L]]))
   class(df) <- "data.frame"
 
   # attempt to copy over index, and set as rownames when appropriate
