@@ -144,7 +144,7 @@ python_info_condaenv <- function(path) {
   python <- file.path(path, suffix)
 
   # find path to conda associated with this env
-  conda <- python_info_condaenv_find(path)
+  conda <- get_python_conda_info(python)$conda
 
   list(
     python = python,
@@ -155,56 +155,6 @@ python_info_condaenv <- function(path) {
 
 }
 
-python_info_condaenv_find <- function(path) {
-
-  # first, check if we have a condabin
-  exe <- if (is_windows()) "conda.exe" else "conda"
-  conda <- file.path(path, "condabin", exe)
-  if (file.exists(conda))
-    return(conda)
-
-  if (is_windows()) {
-    # in Anaconda base env, conda.exe lives under Scripts
-    conda <- file.path(path, "Scripts", exe)
-    if (file.exists(conda))
-      return(conda)
-
-    # in ArcGIS env, conda.exe lives in a parent directory
-    conda <- file.path(path, "../..", "Scripts", exe)
-    conda <- normalizePath(conda, winslash = "/", mustWork = FALSE)
-    if (file.exists(conda))
-      return(conda)
-
-  }
-
-  # read history file
-  histpath <- file.path(path, "conda-meta/history")
-  if (!file.exists(histpath))
-    return(NULL)
-
-  history <- readLines(histpath, warn = FALSE)
-
-  # look for cmd line
-  pattern <- "^[[:space:]]*#[[:space:]]*cmd:[[:space:]]*"
-  lines <- grep(pattern, history, value = TRUE)
-  if (length(lines) == 0)
-    return(NULL)
-
-  # get path to conda script used
-  script <- sub(
-    "^#\\s+cmd: (.+?)\\s+(env\\s+create|create|rename)\\s+.*",
-    "\\1", lines[[1]], perl = TRUE
-  )
-  # on Windows, a wrapper script is recorded in the history,
-  # so instead attempt to find the real conda binary
-  if(is_windows())
-    conda <- file.path(dirname(script), exe)
-  else
-    conda <- script
-  normalizePath(conda, winslash = "/", mustWork = FALSE)
-
-}
-
 python_info_system <- function(path, python) {
 
   list(
